"""GearModalAnalysisAtAStiffness"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
    _5053,
)
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_GEAR_MODAL_ANALYSIS_AT_A_STIFFNESS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtAStiffness",
    "GearModalAnalysisAtAStiffness",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.part_model.gears import _2586
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
        _4977,
        _4984,
        _4986,
        _4987,
        _4989,
        _5002,
        _5005,
        _5020,
        _5022,
        _5027,
        _5036,
        _5040,
        _5043,
        _5046,
        _5076,
        _5082,
        _5085,
        _5087,
        _5088,
        _5100,
        _5103,
        _4997,
        _5055,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7713,
        _7710,
    )
    from mastapy._private.system_model.analyses_and_results import _2740, _2736, _2734

    Self = TypeVar("Self", bound="GearModalAnalysisAtAStiffness")
    CastSelf = TypeVar(
        "CastSelf",
        bound="GearModalAnalysisAtAStiffness._Cast_GearModalAnalysisAtAStiffness",
    )


__docformat__ = "restructuredtext en"
__all__ = ("GearModalAnalysisAtAStiffness",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_GearModalAnalysisAtAStiffness:
    """Special nested class for casting GearModalAnalysisAtAStiffness to subclasses."""

    __parent__: "GearModalAnalysisAtAStiffness"

    @property
    def mountable_component_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5053.MountableComponentModalAnalysisAtAStiffness":
        return self.__parent__._cast(_5053.MountableComponentModalAnalysisAtAStiffness)

    @property
    def component_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_4997.ComponentModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _4997,
        )

        return self.__parent__._cast(_4997.ComponentModalAnalysisAtAStiffness)

    @property
    def part_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5055.PartModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5055,
        )

        return self.__parent__._cast(_5055.PartModalAnalysisAtAStiffness)

    @property
    def part_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7713.PartStaticLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7713,
        )

        return self.__parent__._cast(_7713.PartStaticLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7710.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7710,
        )

        return self.__parent__._cast(_7710.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2740.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2740

        return self.__parent__._cast(_2740.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2736.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2736

        return self.__parent__._cast(_2736.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_4977.AGMAGleasonConicalGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _4977,
        )

        return self.__parent__._cast(
            _4977.AGMAGleasonConicalGearModalAnalysisAtAStiffness
        )

    @property
    def bevel_differential_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_4984.BevelDifferentialGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _4984,
        )

        return self.__parent__._cast(
            _4984.BevelDifferentialGearModalAnalysisAtAStiffness
        )

    @property
    def bevel_differential_planet_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_4986.BevelDifferentialPlanetGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _4986,
        )

        return self.__parent__._cast(
            _4986.BevelDifferentialPlanetGearModalAnalysisAtAStiffness
        )

    @property
    def bevel_differential_sun_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_4987.BevelDifferentialSunGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _4987,
        )

        return self.__parent__._cast(
            _4987.BevelDifferentialSunGearModalAnalysisAtAStiffness
        )

    @property
    def bevel_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_4989.BevelGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _4989,
        )

        return self.__parent__._cast(_4989.BevelGearModalAnalysisAtAStiffness)

    @property
    def concept_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5002.ConceptGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5002,
        )

        return self.__parent__._cast(_5002.ConceptGearModalAnalysisAtAStiffness)

    @property
    def conical_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5005.ConicalGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5005,
        )

        return self.__parent__._cast(_5005.ConicalGearModalAnalysisAtAStiffness)

    @property
    def cylindrical_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5020.CylindricalGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5020,
        )

        return self.__parent__._cast(_5020.CylindricalGearModalAnalysisAtAStiffness)

    @property
    def cylindrical_planet_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5022.CylindricalPlanetGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5022,
        )

        return self.__parent__._cast(
            _5022.CylindricalPlanetGearModalAnalysisAtAStiffness
        )

    @property
    def face_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5027.FaceGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5027,
        )

        return self.__parent__._cast(_5027.FaceGearModalAnalysisAtAStiffness)

    @property
    def hypoid_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5036.HypoidGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5036,
        )

        return self.__parent__._cast(_5036.HypoidGearModalAnalysisAtAStiffness)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5040.KlingelnbergCycloPalloidConicalGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5040,
        )

        return self.__parent__._cast(
            _5040.KlingelnbergCycloPalloidConicalGearModalAnalysisAtAStiffness
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5043.KlingelnbergCycloPalloidHypoidGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5043,
        )

        return self.__parent__._cast(
            _5043.KlingelnbergCycloPalloidHypoidGearModalAnalysisAtAStiffness
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5046.KlingelnbergCycloPalloidSpiralBevelGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5046,
        )

        return self.__parent__._cast(
            _5046.KlingelnbergCycloPalloidSpiralBevelGearModalAnalysisAtAStiffness
        )

    @property
    def spiral_bevel_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5076.SpiralBevelGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5076,
        )

        return self.__parent__._cast(_5076.SpiralBevelGearModalAnalysisAtAStiffness)

    @property
    def straight_bevel_diff_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5082.StraightBevelDiffGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5082,
        )

        return self.__parent__._cast(
            _5082.StraightBevelDiffGearModalAnalysisAtAStiffness
        )

    @property
    def straight_bevel_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5085.StraightBevelGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5085,
        )

        return self.__parent__._cast(_5085.StraightBevelGearModalAnalysisAtAStiffness)

    @property
    def straight_bevel_planet_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5087.StraightBevelPlanetGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5087,
        )

        return self.__parent__._cast(
            _5087.StraightBevelPlanetGearModalAnalysisAtAStiffness
        )

    @property
    def straight_bevel_sun_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5088.StraightBevelSunGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5088,
        )

        return self.__parent__._cast(
            _5088.StraightBevelSunGearModalAnalysisAtAStiffness
        )

    @property
    def worm_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5100.WormGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5100,
        )

        return self.__parent__._cast(_5100.WormGearModalAnalysisAtAStiffness)

    @property
    def zerol_bevel_gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "_5103.ZerolBevelGearModalAnalysisAtAStiffness":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_stiffness import (
            _5103,
        )

        return self.__parent__._cast(_5103.ZerolBevelGearModalAnalysisAtAStiffness)

    @property
    def gear_modal_analysis_at_a_stiffness(
        self: "CastSelf",
    ) -> "GearModalAnalysisAtAStiffness":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class GearModalAnalysisAtAStiffness(_5053.MountableComponentModalAnalysisAtAStiffness):
    """GearModalAnalysisAtAStiffness

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _GEAR_MODAL_ANALYSIS_AT_A_STIFFNESS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def component_design(self: "Self") -> "_2586.Gear":
        """mastapy._private.system_model.part_model.gears.Gear

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_GearModalAnalysisAtAStiffness":
        """Cast to another type.

        Returns:
            _Cast_GearModalAnalysisAtAStiffness
        """
        return _Cast_GearModalAnalysisAtAStiffness(self)



"""SplineFlankContactReporting"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._math.vector_3d import Vector3D
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_SPLINE_FLANK_CONTACT_REPORTING = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections.Reporting",
    "SplineFlankContactReporting",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.math_utility.measured_vectors import _1610

    Self = TypeVar("Self", bound="SplineFlankContactReporting")
    CastSelf = TypeVar(
        "CastSelf",
        bound="SplineFlankContactReporting._Cast_SplineFlankContactReporting",
    )


__docformat__ = "restructuredtext en"
__all__ = ("SplineFlankContactReporting",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_SplineFlankContactReporting:
    """Special nested class for casting SplineFlankContactReporting to subclasses."""

    __parent__: "SplineFlankContactReporting"

    @property
    def spline_flank_contact_reporting(
        self: "CastSelf",
    ) -> "SplineFlankContactReporting":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class SplineFlankContactReporting(_0.APIBase):
    """SplineFlankContactReporting

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _SPLINE_FLANK_CONTACT_REPORTING

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def angle(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Angle

        if temp is None:
            return 0.0

        return temp

    @property
    def entity_name(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.EntityName

        if temp is None:
            return ""

        return temp

    @property
    def normal_deflection(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NormalDeflection

        if temp is None:
            return 0.0

        return temp

    @property
    def normal_force(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NormalForce

        if temp is None:
            return 0.0

        return temp

    @property
    def normal_stiffness(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NormalStiffness

        if temp is None:
            return 0.0

        return temp

    @property
    def relative_deflection_misalignment(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RelativeDeflectionMisalignment

        if temp is None:
            return 0.0

        return temp

    @property
    def surface_penetration(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SurfacePenetration

        if temp is None:
            return 0.0

        return temp

    @property
    def tangential_deflection(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TangentialDeflection

        if temp is None:
            return 0.0

        return temp

    @property
    def tangential_force(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TangentialForce

        if temp is None:
            return 0.0

        return temp

    @property
    def tangential_stiffness(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TangentialStiffness

        if temp is None:
            return 0.0

        return temp

    @property
    def tilt_moment(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TiltMoment

        if temp is None:
            return 0.0

        return temp

    @property
    def contact_position_lcs(self: "Self") -> "Vector3D":
        """Vector3D

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactPositionLCS

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector3d(temp)

        if value is None:
            return None

        return value

    @property
    def contact_position_wcs(self: "Self") -> "Vector3D":
        """Vector3D

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactPositionWCS

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector3d(temp)

        if value is None:
            return None

        return value

    @property
    def force_on_inner_contact_coordinate_system(
        self: "Self",
    ) -> "_1610.VectorWithLinearAndAngularComponents":
        """mastapy._private.math_utility.measured_vectors.VectorWithLinearAndAngularComponents

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ForceOnInnerContactCoordinateSystem

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def force_on_inner_wcs(
        self: "Self",
    ) -> "_1610.VectorWithLinearAndAngularComponents":
        """mastapy._private.math_utility.measured_vectors.VectorWithLinearAndAngularComponents

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ForceOnInnerWCS

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def normal_direction_lcs(self: "Self") -> "Vector3D":
        """Vector3D

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NormalDirectionLCS

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector3d(temp)

        if value is None:
            return None

        return value

    @property
    def normal_direction_wcs(self: "Self") -> "Vector3D":
        """Vector3D

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NormalDirectionWCS

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector3d(temp)

        if value is None:
            return None

        return value

    @property
    def relative_deflection_lcs(
        self: "Self",
    ) -> "_1610.VectorWithLinearAndAngularComponents":
        """mastapy._private.math_utility.measured_vectors.VectorWithLinearAndAngularComponents

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RelativeDeflectionLCS

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def relative_deflection_wcs(
        self: "Self",
    ) -> "_1610.VectorWithLinearAndAngularComponents":
        """mastapy._private.math_utility.measured_vectors.VectorWithLinearAndAngularComponents

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RelativeDeflectionWCS

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_SplineFlankContactReporting":
        """Cast to another type.

        Returns:
            _Cast_SplineFlankContactReporting
        """
        return _Cast_SplineFlankContactReporting(self)



"""ElectricMachineHarmonicLoadDataBase"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from PIL.Image import Image

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal.sentinels import ListWithSelectedItem_None
from mastapy._private._internal import (
    constructor,
    enum_with_selected_value_runtime,
    conversion,
    utility,
)
from mastapy._private._internal.implicit import (
    enum_with_selected_value,
    list_with_selected_item,
)
from mastapy._private.electric_machines.harmonic_load_data import _1428, _1425, _1429
from mastapy._private.electric_machines import _1340
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_ELECTRIC_MACHINE_HARMONIC_LOAD_DATA_BASE = python_net_import(
    "SMT.MastaAPI.ElectricMachines.HarmonicLoadData",
    "ElectricMachineHarmonicLoadDataBase",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.utility_gui.charts import _1918, _1914
    from mastapy._private.math_utility import _1567
    from mastapy._private.electric_machines.harmonic_load_data import (
        _1431,
        _1432,
        _1426,
    )
    from mastapy._private.electric_machines.results import _1367
    from mastapy._private.system_model.analyses_and_results.static_loads import (
        _7018,
        _7019,
        _7020,
        _7021,
        _7022,
        _7023,
        _7024,
    )

    Self = TypeVar("Self", bound="ElectricMachineHarmonicLoadDataBase")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ElectricMachineHarmonicLoadDataBase._Cast_ElectricMachineHarmonicLoadDataBase",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ElectricMachineHarmonicLoadDataBase",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ElectricMachineHarmonicLoadDataBase:
    """Special nested class for casting ElectricMachineHarmonicLoadDataBase to subclasses."""

    __parent__: "ElectricMachineHarmonicLoadDataBase"

    @property
    def speed_dependent_harmonic_load_data(
        self: "CastSelf",
    ) -> "_1429.SpeedDependentHarmonicLoadData":
        return self.__parent__._cast(_1429.SpeedDependentHarmonicLoadData)

    @property
    def harmonic_load_data_base(self: "CastSelf") -> "_1426.HarmonicLoadDataBase":
        from mastapy._private.electric_machines.harmonic_load_data import _1426

        return self.__parent__._cast(_1426.HarmonicLoadDataBase)

    @property
    def dynamic_force_results(self: "CastSelf") -> "_1367.DynamicForceResults":
        from mastapy._private.electric_machines.results import _1367

        return self.__parent__._cast(_1367.DynamicForceResults)

    @property
    def electric_machine_harmonic_load_data(
        self: "CastSelf",
    ) -> "_7018.ElectricMachineHarmonicLoadData":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7018,
        )

        return self.__parent__._cast(_7018.ElectricMachineHarmonicLoadData)

    @property
    def electric_machine_harmonic_load_data_from_excel(
        self: "CastSelf",
    ) -> "_7019.ElectricMachineHarmonicLoadDataFromExcel":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7019,
        )

        return self.__parent__._cast(_7019.ElectricMachineHarmonicLoadDataFromExcel)

    @property
    def electric_machine_harmonic_load_data_from_flux(
        self: "CastSelf",
    ) -> "_7020.ElectricMachineHarmonicLoadDataFromFlux":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7020,
        )

        return self.__parent__._cast(_7020.ElectricMachineHarmonicLoadDataFromFlux)

    @property
    def electric_machine_harmonic_load_data_from_jmag(
        self: "CastSelf",
    ) -> "_7021.ElectricMachineHarmonicLoadDataFromJMAG":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7021,
        )

        return self.__parent__._cast(_7021.ElectricMachineHarmonicLoadDataFromJMAG)

    @property
    def electric_machine_harmonic_load_data_from_masta(
        self: "CastSelf",
    ) -> "_7022.ElectricMachineHarmonicLoadDataFromMASTA":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7022,
        )

        return self.__parent__._cast(_7022.ElectricMachineHarmonicLoadDataFromMASTA)

    @property
    def electric_machine_harmonic_load_data_from_motor_cad(
        self: "CastSelf",
    ) -> "_7023.ElectricMachineHarmonicLoadDataFromMotorCAD":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7023,
        )

        return self.__parent__._cast(_7023.ElectricMachineHarmonicLoadDataFromMotorCAD)

    @property
    def electric_machine_harmonic_load_data_from_motor_packages(
        self: "CastSelf",
    ) -> "_7024.ElectricMachineHarmonicLoadDataFromMotorPackages":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7024,
        )

        return self.__parent__._cast(
            _7024.ElectricMachineHarmonicLoadDataFromMotorPackages
        )

    @property
    def electric_machine_harmonic_load_data_base(
        self: "CastSelf",
    ) -> "ElectricMachineHarmonicLoadDataBase":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ElectricMachineHarmonicLoadDataBase(_1429.SpeedDependentHarmonicLoadData):
    """ElectricMachineHarmonicLoadDataBase

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ELECTRIC_MACHINE_HARMONIC_LOAD_DATA_BASE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def compare_torque_ripple_and_stator_torque_reaction_derived_from_stator_tangential_loads(
        self: "Self",
    ) -> "bool":
        """bool"""
        temp = (
            self.wrapped.CompareTorqueRippleAndStatorTorqueReactionDerivedFromStatorTangentialLoads
        )

        if temp is None:
            return False

        return temp

    @compare_torque_ripple_and_stator_torque_reaction_derived_from_stator_tangential_loads.setter
    @enforce_parameter_types
    def compare_torque_ripple_and_stator_torque_reaction_derived_from_stator_tangential_loads(
        self: "Self", value: "bool"
    ) -> None:
        self.wrapped.CompareTorqueRippleAndStatorTorqueReactionDerivedFromStatorTangentialLoads = (
            bool(value) if value is not None else False
        )

    @property
    def data_type_for_force_moment_distribution_and_temporal_spatial_harmonics_charts(
        self: "Self",
    ) -> "enum_with_selected_value.EnumWithSelectedValue_HarmonicLoadDataType":
        """EnumWithSelectedValue[mastapy._private.electric_machines.harmonic_load_data.HarmonicLoadDataType]"""
        temp = (
            self.wrapped.DataTypeForForceMomentDistributionAndTemporalSpatialHarmonicsCharts
        )

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_HarmonicLoadDataType.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @data_type_for_force_moment_distribution_and_temporal_spatial_harmonics_charts.setter
    @enforce_parameter_types
    def data_type_for_force_moment_distribution_and_temporal_spatial_harmonics_charts(
        self: "Self", value: "_1428.HarmonicLoadDataType"
    ) -> None:
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_HarmonicLoadDataType.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.DataTypeForForceMomentDistributionAndTemporalSpatialHarmonicsCharts = (
            value
        )

    @property
    def display_interpolated_data(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.DisplayInterpolatedData

        if temp is None:
            return False

        return temp

    @display_interpolated_data.setter
    @enforce_parameter_types
    def display_interpolated_data(self: "Self", value: "bool") -> None:
        self.wrapped.DisplayInterpolatedData = (
            bool(value) if value is not None else False
        )

    @property
    def display_option_for_slice_data(
        self: "Self",
    ) -> "enum_with_selected_value.EnumWithSelectedValue_ForceDisplayOption":
        """EnumWithSelectedValue[mastapy._private.electric_machines.harmonic_load_data.ForceDisplayOption]"""
        temp = self.wrapped.DisplayOptionForSliceData

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_ForceDisplayOption.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @display_option_for_slice_data.setter
    @enforce_parameter_types
    def display_option_for_slice_data(
        self: "Self", value: "_1425.ForceDisplayOption"
    ) -> None:
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_ForceDisplayOption.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.DisplayOptionForSliceData = value

    @property
    def force_distribution_3d(self: "Self") -> "_1918.ThreeDVectorChartDefinition":
        """mastapy._private.utility_gui.charts.ThreeDVectorChartDefinition

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ForceDistribution3D

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def force_moment_distribution(self: "Self") -> "Image":
        """Image

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ForceMomentDistribution

        if temp is None:
            return None

        value = conversion.pn_to_mp_smt_bitmap(temp)

        if value is None:
            return None

        return value

    @property
    def invert_axis(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.InvertAxis

        if temp is None:
            return False

        return temp

    @invert_axis.setter
    @enforce_parameter_types
    def invert_axis(self: "Self", value: "bool") -> None:
        self.wrapped.InvertAxis = bool(value) if value is not None else False

    @property
    def plot_as_vectors(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.PlotAsVectors

        if temp is None:
            return False

        return temp

    @plot_as_vectors.setter
    @enforce_parameter_types
    def plot_as_vectors(self: "Self", value: "bool") -> None:
        self.wrapped.PlotAsVectors = bool(value) if value is not None else False

    @property
    def rotor_x_force_amplitude_cut_off(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.RotorXForceAmplitudeCutOff

        if temp is None:
            return 0.0

        return temp

    @rotor_x_force_amplitude_cut_off.setter
    @enforce_parameter_types
    def rotor_x_force_amplitude_cut_off(self: "Self", value: "float") -> None:
        self.wrapped.RotorXForceAmplitudeCutOff = (
            float(value) if value is not None else 0.0
        )

    @property
    def rotor_y_force_amplitude_cut_off(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.RotorYForceAmplitudeCutOff

        if temp is None:
            return 0.0

        return temp

    @rotor_y_force_amplitude_cut_off.setter
    @enforce_parameter_types
    def rotor_y_force_amplitude_cut_off(self: "Self", value: "float") -> None:
        self.wrapped.RotorYForceAmplitudeCutOff = (
            float(value) if value is not None else 0.0
        )

    @property
    def show_all_forces(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.ShowAllForces

        if temp is None:
            return False

        return temp

    @show_all_forces.setter
    @enforce_parameter_types
    def show_all_forces(self: "Self", value: "bool") -> None:
        self.wrapped.ShowAllForces = bool(value) if value is not None else False

    @property
    def show_all_teeth(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.ShowAllTeeth

        if temp is None:
            return False

        return temp

    @show_all_teeth.setter
    @enforce_parameter_types
    def show_all_teeth(self: "Self", value: "bool") -> None:
        self.wrapped.ShowAllTeeth = bool(value) if value is not None else False

    @property
    def slice(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_RotorSkewSlice":
        """ListWithSelectedItem[mastapy._private.electric_machines.RotorSkewSlice]"""
        temp = self.wrapped.Slice

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_RotorSkewSlice",
        )(temp)

    @slice.setter
    @enforce_parameter_types
    def slice(self: "Self", value: "_1340.RotorSkewSlice") -> None:
        wrapper_type = (
            list_with_selected_item.ListWithSelectedItem_RotorSkewSlice.wrapper_type()
        )
        enclosed_type = (
            list_with_selected_item.ListWithSelectedItem_RotorSkewSlice.implicit_type()
        )
        value = wrapper_type[enclosed_type](
            value.wrapped if value is not None else None
        )
        self.wrapped.Slice = value

    @property
    def speed_to_view(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.SpeedToView

        if temp is None:
            return 0.0

        return temp

    @speed_to_view.setter
    @enforce_parameter_types
    def speed_to_view(self: "Self", value: "float") -> None:
        self.wrapped.SpeedToView = float(value) if value is not None else 0.0

    @property
    def stator_axial_loads_amplitude_cut_off(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StatorAxialLoadsAmplitudeCutOff

        if temp is None:
            return 0.0

        return temp

    @stator_axial_loads_amplitude_cut_off.setter
    @enforce_parameter_types
    def stator_axial_loads_amplitude_cut_off(self: "Self", value: "float") -> None:
        self.wrapped.StatorAxialLoadsAmplitudeCutOff = (
            float(value) if value is not None else 0.0
        )

    @property
    def stator_radial_loads_amplitude_cut_off(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StatorRadialLoadsAmplitudeCutOff

        if temp is None:
            return 0.0

        return temp

    @stator_radial_loads_amplitude_cut_off.setter
    @enforce_parameter_types
    def stator_radial_loads_amplitude_cut_off(self: "Self", value: "float") -> None:
        self.wrapped.StatorRadialLoadsAmplitudeCutOff = (
            float(value) if value is not None else 0.0
        )

    @property
    def stator_tangential_loads_amplitude_cut_off(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StatorTangentialLoadsAmplitudeCutOff

        if temp is None:
            return 0.0

        return temp

    @stator_tangential_loads_amplitude_cut_off.setter
    @enforce_parameter_types
    def stator_tangential_loads_amplitude_cut_off(self: "Self", value: "float") -> None:
        self.wrapped.StatorTangentialLoadsAmplitudeCutOff = (
            float(value) if value is not None else 0.0
        )

    @property
    def stator_tooth_moments_amplitude_cut_off(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StatorToothMomentsAmplitudeCutOff

        if temp is None:
            return 0.0

        return temp

    @stator_tooth_moments_amplitude_cut_off.setter
    @enforce_parameter_types
    def stator_tooth_moments_amplitude_cut_off(self: "Self", value: "float") -> None:
        self.wrapped.StatorToothMomentsAmplitudeCutOff = (
            float(value) if value is not None else 0.0
        )

    @property
    def sum_over_all_nodes(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.SumOverAllNodes

        if temp is None:
            return False

        return temp

    @sum_over_all_nodes.setter
    @enforce_parameter_types
    def sum_over_all_nodes(self: "Self", value: "bool") -> None:
        self.wrapped.SumOverAllNodes = bool(value) if value is not None else False

    @property
    def temporal_spatial_harmonics_chart(
        self: "Self",
    ) -> "_1914.ScatterChartDefinition":
        """mastapy._private.utility_gui.charts.ScatterChartDefinition

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TemporalSpatialHarmonicsChart

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def torque_ripple_amplitude_cut_off(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.TorqueRippleAmplitudeCutOff

        if temp is None:
            return 0.0

        return temp

    @torque_ripple_amplitude_cut_off.setter
    @enforce_parameter_types
    def torque_ripple_amplitude_cut_off(self: "Self", value: "float") -> None:
        self.wrapped.TorqueRippleAmplitudeCutOff = (
            float(value) if value is not None else 0.0
        )

    @property
    def use_log_scale_for_temporal_spatial_harmonics_chart(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.UseLogScaleForTemporalSpatialHarmonicsChart

        if temp is None:
            return False

        return temp

    @use_log_scale_for_temporal_spatial_harmonics_chart.setter
    @enforce_parameter_types
    def use_log_scale_for_temporal_spatial_harmonics_chart(
        self: "Self", value: "bool"
    ) -> None:
        self.wrapped.UseLogScaleForTemporalSpatialHarmonicsChart = (
            bool(value) if value is not None else False
        )

    @property
    def rotor_x_force(self: "Self") -> "_1567.MultipleFourierSeriesInterpolator":
        """mastapy._private.math_utility.MultipleFourierSeriesInterpolator

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RotorXForce

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def rotor_y_force(self: "Self") -> "_1567.MultipleFourierSeriesInterpolator":
        """mastapy._private.math_utility.MultipleFourierSeriesInterpolator

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RotorYForce

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def stator_axial_loads(self: "Self") -> "_1431.StatorToothLoadInterpolator":
        """mastapy._private.electric_machines.harmonic_load_data.StatorToothLoadInterpolator

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StatorAxialLoads

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def stator_radial_loads(self: "Self") -> "_1431.StatorToothLoadInterpolator":
        """mastapy._private.electric_machines.harmonic_load_data.StatorToothLoadInterpolator

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StatorRadialLoads

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def stator_tangential_loads(self: "Self") -> "_1431.StatorToothLoadInterpolator":
        """mastapy._private.electric_machines.harmonic_load_data.StatorToothLoadInterpolator

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StatorTangentialLoads

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def stator_tooth_moments(self: "Self") -> "_1432.StatorToothMomentInterpolator":
        """mastapy._private.electric_machines.harmonic_load_data.StatorToothMomentInterpolator

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StatorToothMoments

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @enforce_parameter_types
    def multiple_fourier_series_interpolator_for(
        self: "Self",
        harmonic_load_data_type: "_1428.HarmonicLoadDataType",
        slice_index: "int",
    ) -> "_1567.MultipleFourierSeriesInterpolator":
        """mastapy._private.math_utility.MultipleFourierSeriesInterpolator

        Args:
            harmonic_load_data_type (mastapy._private.electric_machines.harmonic_load_data.HarmonicLoadDataType)
            slice_index (int)
        """
        harmonic_load_data_type = conversion.mp_to_pn_enum(
            harmonic_load_data_type,
            "SMT.MastaAPI.ElectricMachines.HarmonicLoadData.HarmonicLoadDataType",
        )
        slice_index = int(slice_index)
        method_result = self.wrapped.MultipleFourierSeriesInterpolatorFor(
            harmonic_load_data_type, slice_index if slice_index else 0
        )
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @enforce_parameter_types
    def stator_tooth_load_interpolator_for(
        self: "Self",
        harmonic_load_data_type: "_1428.HarmonicLoadDataType",
        slice_index: "int",
    ) -> "_1431.StatorToothLoadInterpolator":
        """mastapy._private.electric_machines.harmonic_load_data.StatorToothLoadInterpolator

        Args:
            harmonic_load_data_type (mastapy._private.electric_machines.harmonic_load_data.HarmonicLoadDataType)
            slice_index (int)
        """
        harmonic_load_data_type = conversion.mp_to_pn_enum(
            harmonic_load_data_type,
            "SMT.MastaAPI.ElectricMachines.HarmonicLoadData.HarmonicLoadDataType",
        )
        slice_index = int(slice_index)
        method_result = self.wrapped.StatorToothLoadInterpolatorFor(
            harmonic_load_data_type, slice_index if slice_index else 0
        )
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @enforce_parameter_types
    def stator_tooth_moment_interpolator_for(
        self: "Self",
        harmonic_load_data_type: "_1428.HarmonicLoadDataType",
        slice_index: "int",
    ) -> "_1432.StatorToothMomentInterpolator":
        """mastapy._private.electric_machines.harmonic_load_data.StatorToothMomentInterpolator

        Args:
            harmonic_load_data_type (mastapy._private.electric_machines.harmonic_load_data.HarmonicLoadDataType)
            slice_index (int)
        """
        harmonic_load_data_type = conversion.mp_to_pn_enum(
            harmonic_load_data_type,
            "SMT.MastaAPI.ElectricMachines.HarmonicLoadData.HarmonicLoadDataType",
        )
        slice_index = int(slice_index)
        method_result = self.wrapped.StatorToothMomentInterpolatorFor(
            harmonic_load_data_type, slice_index if slice_index else 0
        )
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @property
    def cast_to(self: "Self") -> "_Cast_ElectricMachineHarmonicLoadDataBase":
        """Cast to another type.

        Returns:
            _Cast_ElectricMachineHarmonicLoadDataBase
        """
        return _Cast_ElectricMachineHarmonicLoadDataBase(self)



"""NodalComponent"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private.nodal_analysis.nodal_entities import _146
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import
from mastapy._private._internal import utility

_NODAL_COMPONENT = python_net_import(
    "SMT.MastaAPI.NodalAnalysis.NodalEntities", "NodalComponent"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.nodal_analysis.nodal_entities import (
        _126,
        _127,
        _132,
        _133,
        _136,
        _137,
        _139,
        _142,
        _143,
        _148,
        _149,
        _152,
    )
    from mastapy._private.nodal_analysis.nodal_entities.external_force import (
        _156,
        _157,
        _158,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections import (
        _2888,
    )

    Self = TypeVar("Self", bound="NodalComponent")
    CastSelf = TypeVar("CastSelf", bound="NodalComponent._Cast_NodalComponent")


__docformat__ = "restructuredtext en"
__all__ = ("NodalComponent",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_NodalComponent:
    """Special nested class for casting NodalComponent to subclasses."""

    __parent__: "NodalComponent"

    @property
    def nodal_entity(self: "CastSelf") -> "_146.NodalEntity":
        return self.__parent__._cast(_146.NodalEntity)

    @property
    def arbitrary_nodal_component(self: "CastSelf") -> "_126.ArbitraryNodalComponent":
        from mastapy._private.nodal_analysis.nodal_entities import _126

        return self.__parent__._cast(_126.ArbitraryNodalComponent)

    @property
    def bar(self: "CastSelf") -> "_127.Bar":
        from mastapy._private.nodal_analysis.nodal_entities import _127

        return self.__parent__._cast(_127.Bar)

    @property
    def bearing_axial_mounting_clearance(
        self: "CastSelf",
    ) -> "_132.BearingAxialMountingClearance":
        from mastapy._private.nodal_analysis.nodal_entities import _132

        return self.__parent__._cast(_132.BearingAxialMountingClearance)

    @property
    def cms_nodal_component(self: "CastSelf") -> "_133.CMSNodalComponent":
        from mastapy._private.nodal_analysis.nodal_entities import _133

        return self.__parent__._cast(_133.CMSNodalComponent)

    @property
    def distributed_rigid_bar_coupling(
        self: "CastSelf",
    ) -> "_136.DistributedRigidBarCoupling":
        from mastapy._private.nodal_analysis.nodal_entities import _136

        return self.__parent__._cast(_136.DistributedRigidBarCoupling)

    @property
    def friction_nodal_component(self: "CastSelf") -> "_137.FrictionNodalComponent":
        from mastapy._private.nodal_analysis.nodal_entities import _137

        return self.__parent__._cast(_137.FrictionNodalComponent)

    @property
    def gear_mesh_node_pair(self: "CastSelf") -> "_139.GearMeshNodePair":
        from mastapy._private.nodal_analysis.nodal_entities import _139

        return self.__parent__._cast(_139.GearMeshNodePair)

    @property
    def inertial_force_component(self: "CastSelf") -> "_142.InertialForceComponent":
        from mastapy._private.nodal_analysis.nodal_entities import _142

        return self.__parent__._cast(_142.InertialForceComponent)

    @property
    def line_contact_stiffness_entity(
        self: "CastSelf",
    ) -> "_143.LineContactStiffnessEntity":
        from mastapy._private.nodal_analysis.nodal_entities import _143

        return self.__parent__._cast(_143.LineContactStiffnessEntity)

    @property
    def pid_control_nodal_component(
        self: "CastSelf",
    ) -> "_148.PIDControlNodalComponent":
        from mastapy._private.nodal_analysis.nodal_entities import _148

        return self.__parent__._cast(_148.PIDControlNodalComponent)

    @property
    def rigid_bar(self: "CastSelf") -> "_149.RigidBar":
        from mastapy._private.nodal_analysis.nodal_entities import _149

        return self.__parent__._cast(_149.RigidBar)

    @property
    def surface_to_surface_contact_stiffness_entity(
        self: "CastSelf",
    ) -> "_152.SurfaceToSurfaceContactStiffnessEntity":
        from mastapy._private.nodal_analysis.nodal_entities import _152

        return self.__parent__._cast(_152.SurfaceToSurfaceContactStiffnessEntity)

    @property
    def external_force_entity(self: "CastSelf") -> "_156.ExternalForceEntity":
        from mastapy._private.nodal_analysis.nodal_entities.external_force import _156

        return self.__parent__._cast(_156.ExternalForceEntity)

    @property
    def external_force_line_contact_entity(
        self: "CastSelf",
    ) -> "_157.ExternalForceLineContactEntity":
        from mastapy._private.nodal_analysis.nodal_entities.external_force import _157

        return self.__parent__._cast(_157.ExternalForceLineContactEntity)

    @property
    def external_force_single_point_entity(
        self: "CastSelf",
    ) -> "_158.ExternalForceSinglePointEntity":
        from mastapy._private.nodal_analysis.nodal_entities.external_force import _158

        return self.__parent__._cast(_158.ExternalForceSinglePointEntity)

    @property
    def shaft_section_system_deflection(
        self: "CastSelf",
    ) -> "_2888.ShaftSectionSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2888,
        )

        return self.__parent__._cast(_2888.ShaftSectionSystemDeflection)

    @property
    def nodal_component(self: "CastSelf") -> "NodalComponent":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class NodalComponent(_146.NodalEntity):
    """NodalComponent

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _NODAL_COMPONENT

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_NodalComponent":
        """Cast to another type.

        Returns:
            _Cast_NodalComponent
        """
        return _Cast_NodalComponent(self)



"""GleasonHypoidMeshSingleFlankRating"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, utility
from mastapy._private._internal.implicit import overridable
from mastapy._private.gears.rating.conical import _557
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_GLEASON_HYPOID_MESH_SINGLE_FLANK_RATING = python_net_import(
    "SMT.MastaAPI.Gears.Rating.Hypoid.Standards", "GleasonHypoidMeshSingleFlankRating"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.rating import _377

    Self = TypeVar("Self", bound="GleasonHypoidMeshSingleFlankRating")
    CastSelf = TypeVar(
        "CastSelf",
        bound="GleasonHypoidMeshSingleFlankRating._Cast_GleasonHypoidMeshSingleFlankRating",
    )


__docformat__ = "restructuredtext en"
__all__ = ("GleasonHypoidMeshSingleFlankRating",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_GleasonHypoidMeshSingleFlankRating:
    """Special nested class for casting GleasonHypoidMeshSingleFlankRating to subclasses."""

    __parent__: "GleasonHypoidMeshSingleFlankRating"

    @property
    def conical_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_557.ConicalMeshSingleFlankRating":
        return self.__parent__._cast(_557.ConicalMeshSingleFlankRating)

    @property
    def mesh_single_flank_rating(self: "CastSelf") -> "_377.MeshSingleFlankRating":
        from mastapy._private.gears.rating import _377

        return self.__parent__._cast(_377.MeshSingleFlankRating)

    @property
    def gleason_hypoid_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "GleasonHypoidMeshSingleFlankRating":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class GleasonHypoidMeshSingleFlankRating(_557.ConicalMeshSingleFlankRating):
    """GleasonHypoidMeshSingleFlankRating

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _GLEASON_HYPOID_MESH_SINGLE_FLANK_RATING

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def calculated_contact_stress(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CalculatedContactStress

        if temp is None:
            return 0.0

        return temp

    @property
    def dynamic_factor_bending(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DynamicFactorBending

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    def dynamic_factor_contact(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DynamicFactorContact

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    def elastic_coefficient(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ElasticCoefficient

        if temp is None:
            return 0.0

        return temp

    @property
    def geometry_factor_i(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GeometryFactorI

        if temp is None:
            return 0.0

        return temp

    @property
    def load_distribution_factor_bending(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LoadDistributionFactorBending

        if temp is None:
            return 0.0

        return temp

    @property
    def load_distribution_factor_contact(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LoadDistributionFactorContact

        if temp is None:
            return 0.0

        return temp

    @property
    def overload_factor_bending(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OverloadFactorBending

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    def overload_factor_contact(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OverloadFactorContact

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    def rating_standard_name(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RatingStandardName

        if temp is None:
            return ""

        return temp

    @property
    def size_factor_bending(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SizeFactorBending

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    def size_factor_contact(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SizeFactorContact

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    def surface_condition_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SurfaceConditionFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def temperature_factor_bending(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TemperatureFactorBending

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    def temperature_factor_contact(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TemperatureFactorContact

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    def transmitted_tangential_load_at_large_end(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TransmittedTangentialLoadAtLargeEnd

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(self: "Self") -> "_Cast_GleasonHypoidMeshSingleFlankRating":
        """Cast to another type.

        Returns:
            _Cast_GleasonHypoidMeshSingleFlankRating
        """
        return _Cast_GleasonHypoidMeshSingleFlankRating(self)



"""ModalAnalysisOptions"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal.implicit import overridable
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private._internal import constructor, utility
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_MODAL_ANALYSIS_OPTIONS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses", "ModalAnalysisOptions"
)

if TYPE_CHECKING:
    from typing import Any, Type, Union, Tuple, TypeVar

    from mastapy._private.system_model.analyses_and_results.modal_analyses import _4745

    Self = TypeVar("Self", bound="ModalAnalysisOptions")
    CastSelf = TypeVar(
        "CastSelf", bound="ModalAnalysisOptions._Cast_ModalAnalysisOptions"
    )


__docformat__ = "restructuredtext en"
__all__ = ("ModalAnalysisOptions",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ModalAnalysisOptions:
    """Special nested class for casting ModalAnalysisOptions to subclasses."""

    __parent__: "ModalAnalysisOptions"

    @property
    def modal_analysis_options(self: "CastSelf") -> "ModalAnalysisOptions":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ModalAnalysisOptions(_0.APIBase):
    """ModalAnalysisOptions

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _MODAL_ANALYSIS_OPTIONS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def maximum_mode_frequency(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.MaximumModeFrequency

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @maximum_mode_frequency.setter
    @enforce_parameter_types
    def maximum_mode_frequency(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.MaximumModeFrequency = value

    @property
    def number_of_modes(self: "Self") -> "overridable.Overridable_int":
        """Overridable[int]"""
        temp = self.wrapped.NumberOfModes

        if temp is None:
            return 0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_int"
        )(temp)

    @number_of_modes.setter
    @enforce_parameter_types
    def number_of_modes(self: "Self", value: "Union[int, Tuple[int, bool]]") -> None:
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0, is_overridden
        )
        self.wrapped.NumberOfModes = value

    @property
    def use_single_pass_eigensolver(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.UseSinglePassEigensolver

        if temp is None:
            return False

        return temp

    @use_single_pass_eigensolver.setter
    @enforce_parameter_types
    def use_single_pass_eigensolver(self: "Self", value: "bool") -> None:
        self.wrapped.UseSinglePassEigensolver = (
            bool(value) if value is not None else False
        )

    @property
    def frequency_response_options_for_reports(
        self: "Self",
    ) -> "_4745.FrequencyResponseAnalysisOptions":
        """mastapy._private.system_model.analyses_and_results.modal_analyses.FrequencyResponseAnalysisOptions

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FrequencyResponseOptionsForReports

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_ModalAnalysisOptions":
        """Cast to another type.

        Returns:
            _Cast_ModalAnalysisOptions
        """
        return _Cast_ModalAnalysisOptions(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.gears.gear_set_pareto_optimiser._925 import BarForPareto
    from mastapy._private.gears.gear_set_pareto_optimiser._926 import (
        CandidateDisplayChoice,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._927 import ChartInfoBase
    from mastapy._private.gears.gear_set_pareto_optimiser._928 import (
        CylindricalGearSetParetoOptimiser,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._929 import (
        DesignSpaceSearchBase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._930 import (
        DesignSpaceSearchCandidateBase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._931 import (
        FaceGearSetParetoOptimiser,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._932 import GearNameMapper
    from mastapy._private.gears.gear_set_pareto_optimiser._933 import GearNamePicker
    from mastapy._private.gears.gear_set_pareto_optimiser._934 import (
        GearSetOptimiserCandidate,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._935 import (
        GearSetParetoOptimiser,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._936 import (
        HypoidGearSetParetoOptimiser,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._937 import (
        InputSliderForPareto,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._938 import LargerOrSmaller
    from mastapy._private.gears.gear_set_pareto_optimiser._939 import (
        MicroGeometryDesignSpaceSearch,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._940 import (
        MicroGeometryDesignSpaceSearchCandidate,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._941 import (
        MicroGeometryDesignSpaceSearchChartInformation,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._942 import (
        MicroGeometryDesignSpaceSearchStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._943 import (
        MicroGeometryGearSetDesignSpaceSearch,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._944 import (
        MicroGeometryGearSetDesignSpaceSearchStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._945 import (
        MicroGeometryGearSetDutyCycleDesignSpaceSearchStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._946 import OptimisationTarget
    from mastapy._private.gears.gear_set_pareto_optimiser._947 import (
        ParetoConicalRatingOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._948 import (
        ParetoCylindricalGearSetDutyCycleOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._949 import (
        ParetoCylindricalGearSetOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._950 import (
        ParetoCylindricalRatingOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._951 import (
        ParetoFaceGearSetDutyCycleOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._952 import (
        ParetoFaceGearSetOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._953 import (
        ParetoFaceRatingOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._954 import (
        ParetoHypoidGearSetDutyCycleOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._955 import (
        ParetoHypoidGearSetOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._956 import (
        ParetoOptimiserChartInformation,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._957 import (
        ParetoSpiralBevelGearSetDutyCycleOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._958 import (
        ParetoSpiralBevelGearSetOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._959 import (
        ParetoStraightBevelGearSetDutyCycleOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._960 import (
        ParetoStraightBevelGearSetOptimisationStrategyDatabase,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._961 import (
        ReasonsForInvalidDesigns,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._962 import (
        SpiralBevelGearSetParetoOptimiser,
    )
    from mastapy._private.gears.gear_set_pareto_optimiser._963 import (
        StraightBevelGearSetParetoOptimiser,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.gears.gear_set_pareto_optimiser._925": ["BarForPareto"],
        "_private.gears.gear_set_pareto_optimiser._926": ["CandidateDisplayChoice"],
        "_private.gears.gear_set_pareto_optimiser._927": ["ChartInfoBase"],
        "_private.gears.gear_set_pareto_optimiser._928": [
            "CylindricalGearSetParetoOptimiser"
        ],
        "_private.gears.gear_set_pareto_optimiser._929": ["DesignSpaceSearchBase"],
        "_private.gears.gear_set_pareto_optimiser._930": [
            "DesignSpaceSearchCandidateBase"
        ],
        "_private.gears.gear_set_pareto_optimiser._931": ["FaceGearSetParetoOptimiser"],
        "_private.gears.gear_set_pareto_optimiser._932": ["GearNameMapper"],
        "_private.gears.gear_set_pareto_optimiser._933": ["GearNamePicker"],
        "_private.gears.gear_set_pareto_optimiser._934": ["GearSetOptimiserCandidate"],
        "_private.gears.gear_set_pareto_optimiser._935": ["GearSetParetoOptimiser"],
        "_private.gears.gear_set_pareto_optimiser._936": [
            "HypoidGearSetParetoOptimiser"
        ],
        "_private.gears.gear_set_pareto_optimiser._937": ["InputSliderForPareto"],
        "_private.gears.gear_set_pareto_optimiser._938": ["LargerOrSmaller"],
        "_private.gears.gear_set_pareto_optimiser._939": [
            "MicroGeometryDesignSpaceSearch"
        ],
        "_private.gears.gear_set_pareto_optimiser._940": [
            "MicroGeometryDesignSpaceSearchCandidate"
        ],
        "_private.gears.gear_set_pareto_optimiser._941": [
            "MicroGeometryDesignSpaceSearchChartInformation"
        ],
        "_private.gears.gear_set_pareto_optimiser._942": [
            "MicroGeometryDesignSpaceSearchStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._943": [
            "MicroGeometryGearSetDesignSpaceSearch"
        ],
        "_private.gears.gear_set_pareto_optimiser._944": [
            "MicroGeometryGearSetDesignSpaceSearchStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._945": [
            "MicroGeometryGearSetDutyCycleDesignSpaceSearchStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._946": ["OptimisationTarget"],
        "_private.gears.gear_set_pareto_optimiser._947": [
            "ParetoConicalRatingOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._948": [
            "ParetoCylindricalGearSetDutyCycleOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._949": [
            "ParetoCylindricalGearSetOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._950": [
            "ParetoCylindricalRatingOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._951": [
            "ParetoFaceGearSetDutyCycleOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._952": [
            "ParetoFaceGearSetOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._953": [
            "ParetoFaceRatingOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._954": [
            "ParetoHypoidGearSetDutyCycleOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._955": [
            "ParetoHypoidGearSetOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._956": [
            "ParetoOptimiserChartInformation"
        ],
        "_private.gears.gear_set_pareto_optimiser._957": [
            "ParetoSpiralBevelGearSetDutyCycleOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._958": [
            "ParetoSpiralBevelGearSetOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._959": [
            "ParetoStraightBevelGearSetDutyCycleOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._960": [
            "ParetoStraightBevelGearSetOptimisationStrategyDatabase"
        ],
        "_private.gears.gear_set_pareto_optimiser._961": ["ReasonsForInvalidDesigns"],
        "_private.gears.gear_set_pareto_optimiser._962": [
            "SpiralBevelGearSetParetoOptimiser"
        ],
        "_private.gears.gear_set_pareto_optimiser._963": [
            "StraightBevelGearSetParetoOptimiser"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "BarForPareto",
    "CandidateDisplayChoice",
    "ChartInfoBase",
    "CylindricalGearSetParetoOptimiser",
    "DesignSpaceSearchBase",
    "DesignSpaceSearchCandidateBase",
    "FaceGearSetParetoOptimiser",
    "GearNameMapper",
    "GearNamePicker",
    "GearSetOptimiserCandidate",
    "GearSetParetoOptimiser",
    "HypoidGearSetParetoOptimiser",
    "InputSliderForPareto",
    "LargerOrSmaller",
    "MicroGeometryDesignSpaceSearch",
    "MicroGeometryDesignSpaceSearchCandidate",
    "MicroGeometryDesignSpaceSearchChartInformation",
    "MicroGeometryDesignSpaceSearchStrategyDatabase",
    "MicroGeometryGearSetDesignSpaceSearch",
    "MicroGeometryGearSetDesignSpaceSearchStrategyDatabase",
    "MicroGeometryGearSetDutyCycleDesignSpaceSearchStrategyDatabase",
    "OptimisationTarget",
    "ParetoConicalRatingOptimisationStrategyDatabase",
    "ParetoCylindricalGearSetDutyCycleOptimisationStrategyDatabase",
    "ParetoCylindricalGearSetOptimisationStrategyDatabase",
    "ParetoCylindricalRatingOptimisationStrategyDatabase",
    "ParetoFaceGearSetDutyCycleOptimisationStrategyDatabase",
    "ParetoFaceGearSetOptimisationStrategyDatabase",
    "ParetoFaceRatingOptimisationStrategyDatabase",
    "ParetoHypoidGearSetDutyCycleOptimisationStrategyDatabase",
    "ParetoHypoidGearSetOptimisationStrategyDatabase",
    "ParetoOptimiserChartInformation",
    "ParetoSpiralBevelGearSetDutyCycleOptimisationStrategyDatabase",
    "ParetoSpiralBevelGearSetOptimisationStrategyDatabase",
    "ParetoStraightBevelGearSetDutyCycleOptimisationStrategyDatabase",
    "ParetoStraightBevelGearSetOptimisationStrategyDatabase",
    "ReasonsForInvalidDesigns",
    "SpiralBevelGearSetParetoOptimiser",
    "StraightBevelGearSetParetoOptimiser",
)



"""FEPartSystemDeflection"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.system_deflections import _2769
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_FE_PART_SYSTEM_DEFLECTION = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections",
    "FEPartSystemDeflection",
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.system_model.part_model import _2507
    from mastapy._private.system_model.analyses_and_results.static_loads import _7034
    from mastapy._private.nodal_analysis.component_mode_synthesis import _246
    from mastapy._private.nodal_analysis import _79
    from mastapy._private.system_model.analyses_and_results.power_flows import _4194
    from mastapy._private.math_utility.measured_vectors import _1610, _1606
    from mastapy._private.system_model.fe import _2464
    from mastapy._private.system_model.analyses_and_results.system_deflections import (
        _2798,
        _2870,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7712,
        _7713,
        _7710,
    )
    from mastapy._private.system_model.analyses_and_results import _2740, _2736, _2734

    Self = TypeVar("Self", bound="FEPartSystemDeflection")
    CastSelf = TypeVar(
        "CastSelf", bound="FEPartSystemDeflection._Cast_FEPartSystemDeflection"
    )


__docformat__ = "restructuredtext en"
__all__ = ("FEPartSystemDeflection",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_FEPartSystemDeflection:
    """Special nested class for casting FEPartSystemDeflection to subclasses."""

    __parent__: "FEPartSystemDeflection"

    @property
    def abstract_shaft_or_housing_system_deflection(
        self: "CastSelf",
    ) -> "_2769.AbstractShaftOrHousingSystemDeflection":
        return self.__parent__._cast(_2769.AbstractShaftOrHousingSystemDeflection)

    @property
    def component_system_deflection(
        self: "CastSelf",
    ) -> "_2798.ComponentSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2798,
        )

        return self.__parent__._cast(_2798.ComponentSystemDeflection)

    @property
    def part_system_deflection(self: "CastSelf") -> "_2870.PartSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.system_deflections import (
            _2870,
        )

        return self.__parent__._cast(_2870.PartSystemDeflection)

    @property
    def part_fe_analysis(self: "CastSelf") -> "_7712.PartFEAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7712,
        )

        return self.__parent__._cast(_7712.PartFEAnalysis)

    @property
    def part_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7713.PartStaticLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7713,
        )

        return self.__parent__._cast(_7713.PartStaticLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7710.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7710,
        )

        return self.__parent__._cast(_7710.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2740.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2740

        return self.__parent__._cast(_2740.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2736.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2736

        return self.__parent__._cast(_2736.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def fe_part_system_deflection(self: "CastSelf") -> "FEPartSystemDeflection":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class FEPartSystemDeflection(_2769.AbstractShaftOrHousingSystemDeflection):
    """FEPartSystemDeflection

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _FE_PART_SYSTEM_DEFLECTION

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def component_design(self: "Self") -> "_2507.FEPart":
        """mastapy._private.system_model.part_model.FEPart

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def component_load_case(self: "Self") -> "_7034.FEPartLoadCase":
        """mastapy._private.system_model.analyses_and_results.static_loads.FEPartLoadCase

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ComponentLoadCase

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def full_fe_results(self: "Self") -> "_246.StaticCMSResults":
        """mastapy._private.nodal_analysis.component_mode_synthesis.StaticCMSResults

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FullFEResults

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def mass_in_world_coordinate_system_mn_rad_s_kg(self: "Self") -> "_79.NodalMatrix":
        """mastapy._private.nodal_analysis.NodalMatrix

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MassInWorldCoordinateSystemMNRadSKg

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def power_flow_results(self: "Self") -> "_4194.FEPartPowerFlow":
        """mastapy._private.system_model.analyses_and_results.power_flows.FEPartPowerFlow

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PowerFlowResults

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def stiffness_in_world_coordinate_system_mn_rad(self: "Self") -> "_79.NodalMatrix":
        """mastapy._private.nodal_analysis.NodalMatrix

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StiffnessInWorldCoordinateSystemMNRad

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def applied_internal_forces_in_world_coordinate_system(
        self: "Self",
    ) -> "List[_1610.VectorWithLinearAndAngularComponents]":
        """List[mastapy._private.math_utility.measured_vectors.VectorWithLinearAndAngularComponents]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AppliedInternalForcesInWorldCoordinateSystem

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def node_results_in_shaft_coordinate_system(
        self: "Self",
    ) -> "List[_1606.ForceAndDisplacementResults]":
        """List[mastapy._private.math_utility.measured_vectors.ForceAndDisplacementResults]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NodeResultsInShaftCoordinateSystem

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def planetaries(self: "Self") -> "List[FEPartSystemDeflection]":
        """List[mastapy._private.system_model.analyses_and_results.system_deflections.FEPartSystemDeflection]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Planetaries

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def export(self: "Self") -> "_2464.SystemDeflectionFEExportOptions":
        """mastapy._private.system_model.fe.SystemDeflectionFEExportOptions

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Export

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    def export_displacements(self: "Self") -> None:
        """Method does not return."""
        self.wrapped.ExportDisplacements()

    def export_forces(self: "Self") -> None:
        """Method does not return."""
        self.wrapped.ExportForces()

    @property
    def cast_to(self: "Self") -> "_Cast_FEPartSystemDeflection":
        """Cast to another type.

        Returns:
            _Cast_FEPartSystemDeflection
        """
        return _Cast_FEPartSystemDeflection(self)



"""BearingCatalog"""
from __future__ import annotations

from typing import TYPE_CHECKING
from enum import Enum

from mastapy._private._internal.python_net import python_net_import

_BEARING_CATALOG = python_net_import("SMT.MastaAPI.Bearings", "BearingCatalog")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="BearingCatalog")
    CastSelf = TypeVar("CastSelf", bound="BearingCatalog._Cast_BearingCatalog")


__docformat__ = "restructuredtext en"
__all__ = ("BearingCatalog",)


class BearingCatalog(Enum):
    """BearingCatalog

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _BEARING_CATALOG

    ALL = 0
    TIMKEN = 1
    SKF = 2
    NSK = 3
    INA = 4
    FAG = 5
    JTEKT_KOYO = 6
    NTN = 7
    CUSTOM = 8
    SKF_LEGACY = 9
    SCHAEFFLER_LEGACY = 10
    TIMKEN_LEGACY = 11
    NACHI = 12
    ILJIN = 13
    NES = 14


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


BearingCatalog.__setattr__ = __enum_setattr
BearingCatalog.__delattr__ = __enum_delattr



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6548 import (
        AbstractAssemblyCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6549 import (
        AbstractShaftCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6550 import (
        AbstractShaftOrHousingCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6551 import (
        AbstractShaftToMountableComponentConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6552 import (
        AGMAGleasonConicalGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6553 import (
        AGMAGleasonConicalGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6554 import (
        AGMAGleasonConicalGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6555 import (
        AssemblyCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6556 import (
        BearingCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6557 import (
        BeltConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6558 import (
        BeltDriveCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6559 import (
        BevelDifferentialGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6560 import (
        BevelDifferentialGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6561 import (
        BevelDifferentialGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6562 import (
        BevelDifferentialPlanetGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6563 import (
        BevelDifferentialSunGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6564 import (
        BevelGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6565 import (
        BevelGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6566 import (
        BevelGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6567 import (
        BoltCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6568 import (
        BoltedJointCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6569 import (
        ClutchCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6570 import (
        ClutchConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6571 import (
        ClutchHalfCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6572 import (
        CoaxialConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6573 import (
        ComponentCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6574 import (
        ConceptCouplingCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6575 import (
        ConceptCouplingConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6576 import (
        ConceptCouplingHalfCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6577 import (
        ConceptGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6578 import (
        ConceptGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6579 import (
        ConceptGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6580 import (
        ConicalGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6581 import (
        ConicalGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6582 import (
        ConicalGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6583 import (
        ConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6584 import (
        ConnectorCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6585 import (
        CouplingCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6586 import (
        CouplingConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6587 import (
        CouplingHalfCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6588 import (
        CVTBeltConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6589 import (
        CVTCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6590 import (
        CVTPulleyCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6591 import (
        CycloidalAssemblyCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6592 import (
        CycloidalDiscCentralBearingConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6593 import (
        CycloidalDiscCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6594 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6595 import (
        CylindricalGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6596 import (
        CylindricalGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6597 import (
        CylindricalGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6598 import (
        CylindricalPlanetGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6599 import (
        DatumCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6600 import (
        ExternalCADModelCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6601 import (
        FaceGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6602 import (
        FaceGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6603 import (
        FaceGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6604 import (
        FEPartCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6605 import (
        FlexiblePinAssemblyCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6606 import (
        GearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6607 import (
        GearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6608 import (
        GearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6609 import (
        GuideDxfModelCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6610 import (
        HypoidGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6611 import (
        HypoidGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6612 import (
        HypoidGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6613 import (
        InterMountableComponentConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6614 import (
        KlingelnbergCycloPalloidConicalGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6615 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6616 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6617 import (
        KlingelnbergCycloPalloidHypoidGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6618 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6619 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6620 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6621 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6622 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6623 import (
        MassDiscCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6624 import (
        MeasurementComponentCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6625 import (
        MicrophoneArrayCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6626 import (
        MicrophoneCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6627 import (
        MountableComponentCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6628 import (
        OilSealCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6629 import (
        PartCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6630 import (
        PartToPartShearCouplingCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6631 import (
        PartToPartShearCouplingConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6632 import (
        PartToPartShearCouplingHalfCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6633 import (
        PlanetaryConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6634 import (
        PlanetaryGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6635 import (
        PlanetCarrierCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6636 import (
        PointLoadCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6637 import (
        PowerLoadCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6638 import (
        PulleyCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6639 import (
        RingPinsCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6640 import (
        RingPinsToDiscConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6641 import (
        RollingRingAssemblyCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6642 import (
        RollingRingCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6643 import (
        RollingRingConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6644 import (
        RootAssemblyCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6645 import (
        ShaftCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6646 import (
        ShaftHubConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6647 import (
        ShaftToMountableComponentConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6648 import (
        SpecialisedAssemblyCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6649 import (
        SpiralBevelGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6650 import (
        SpiralBevelGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6651 import (
        SpiralBevelGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6652 import (
        SpringDamperCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6653 import (
        SpringDamperConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6654 import (
        SpringDamperHalfCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6655 import (
        StraightBevelDiffGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6656 import (
        StraightBevelDiffGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6657 import (
        StraightBevelDiffGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6658 import (
        StraightBevelGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6659 import (
        StraightBevelGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6660 import (
        StraightBevelGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6661 import (
        StraightBevelPlanetGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6662 import (
        StraightBevelSunGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6663 import (
        SynchroniserCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6664 import (
        SynchroniserHalfCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6665 import (
        SynchroniserPartCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6666 import (
        SynchroniserSleeveCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6667 import (
        TorqueConverterCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6668 import (
        TorqueConverterConnectionCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6669 import (
        TorqueConverterPumpCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6670 import (
        TorqueConverterTurbineCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6671 import (
        UnbalancedMassCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6672 import (
        VirtualComponentCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6673 import (
        WormGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6674 import (
        WormGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6675 import (
        WormGearSetCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6676 import (
        ZerolBevelGearCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6677 import (
        ZerolBevelGearMeshCompoundDynamicAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.dynamic_analyses.compound._6678 import (
        ZerolBevelGearSetCompoundDynamicAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6548": [
            "AbstractAssemblyCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6549": [
            "AbstractShaftCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6550": [
            "AbstractShaftOrHousingCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6551": [
            "AbstractShaftToMountableComponentConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6552": [
            "AGMAGleasonConicalGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6553": [
            "AGMAGleasonConicalGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6554": [
            "AGMAGleasonConicalGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6555": [
            "AssemblyCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6556": [
            "BearingCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6557": [
            "BeltConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6558": [
            "BeltDriveCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6559": [
            "BevelDifferentialGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6560": [
            "BevelDifferentialGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6561": [
            "BevelDifferentialGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6562": [
            "BevelDifferentialPlanetGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6563": [
            "BevelDifferentialSunGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6564": [
            "BevelGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6565": [
            "BevelGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6566": [
            "BevelGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6567": [
            "BoltCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6568": [
            "BoltedJointCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6569": [
            "ClutchCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6570": [
            "ClutchConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6571": [
            "ClutchHalfCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6572": [
            "CoaxialConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6573": [
            "ComponentCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6574": [
            "ConceptCouplingCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6575": [
            "ConceptCouplingConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6576": [
            "ConceptCouplingHalfCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6577": [
            "ConceptGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6578": [
            "ConceptGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6579": [
            "ConceptGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6580": [
            "ConicalGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6581": [
            "ConicalGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6582": [
            "ConicalGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6583": [
            "ConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6584": [
            "ConnectorCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6585": [
            "CouplingCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6586": [
            "CouplingConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6587": [
            "CouplingHalfCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6588": [
            "CVTBeltConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6589": [
            "CVTCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6590": [
            "CVTPulleyCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6591": [
            "CycloidalAssemblyCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6592": [
            "CycloidalDiscCentralBearingConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6593": [
            "CycloidalDiscCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6594": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6595": [
            "CylindricalGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6596": [
            "CylindricalGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6597": [
            "CylindricalGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6598": [
            "CylindricalPlanetGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6599": [
            "DatumCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6600": [
            "ExternalCADModelCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6601": [
            "FaceGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6602": [
            "FaceGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6603": [
            "FaceGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6604": [
            "FEPartCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6605": [
            "FlexiblePinAssemblyCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6606": [
            "GearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6607": [
            "GearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6608": [
            "GearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6609": [
            "GuideDxfModelCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6610": [
            "HypoidGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6611": [
            "HypoidGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6612": [
            "HypoidGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6613": [
            "InterMountableComponentConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6614": [
            "KlingelnbergCycloPalloidConicalGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6615": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6616": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6617": [
            "KlingelnbergCycloPalloidHypoidGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6618": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6619": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6620": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6621": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6622": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6623": [
            "MassDiscCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6624": [
            "MeasurementComponentCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6625": [
            "MicrophoneArrayCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6626": [
            "MicrophoneCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6627": [
            "MountableComponentCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6628": [
            "OilSealCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6629": [
            "PartCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6630": [
            "PartToPartShearCouplingCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6631": [
            "PartToPartShearCouplingConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6632": [
            "PartToPartShearCouplingHalfCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6633": [
            "PlanetaryConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6634": [
            "PlanetaryGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6635": [
            "PlanetCarrierCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6636": [
            "PointLoadCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6637": [
            "PowerLoadCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6638": [
            "PulleyCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6639": [
            "RingPinsCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6640": [
            "RingPinsToDiscConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6641": [
            "RollingRingAssemblyCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6642": [
            "RollingRingCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6643": [
            "RollingRingConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6644": [
            "RootAssemblyCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6645": [
            "ShaftCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6646": [
            "ShaftHubConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6647": [
            "ShaftToMountableComponentConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6648": [
            "SpecialisedAssemblyCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6649": [
            "SpiralBevelGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6650": [
            "SpiralBevelGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6651": [
            "SpiralBevelGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6652": [
            "SpringDamperCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6653": [
            "SpringDamperConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6654": [
            "SpringDamperHalfCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6655": [
            "StraightBevelDiffGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6656": [
            "StraightBevelDiffGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6657": [
            "StraightBevelDiffGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6658": [
            "StraightBevelGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6659": [
            "StraightBevelGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6660": [
            "StraightBevelGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6661": [
            "StraightBevelPlanetGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6662": [
            "StraightBevelSunGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6663": [
            "SynchroniserCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6664": [
            "SynchroniserHalfCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6665": [
            "SynchroniserPartCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6666": [
            "SynchroniserSleeveCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6667": [
            "TorqueConverterCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6668": [
            "TorqueConverterConnectionCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6669": [
            "TorqueConverterPumpCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6670": [
            "TorqueConverterTurbineCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6671": [
            "UnbalancedMassCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6672": [
            "VirtualComponentCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6673": [
            "WormGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6674": [
            "WormGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6675": [
            "WormGearSetCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6676": [
            "ZerolBevelGearCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6677": [
            "ZerolBevelGearMeshCompoundDynamicAnalysis"
        ],
        "_private.system_model.analyses_and_results.dynamic_analyses.compound._6678": [
            "ZerolBevelGearSetCompoundDynamicAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundDynamicAnalysis",
    "AbstractShaftCompoundDynamicAnalysis",
    "AbstractShaftOrHousingCompoundDynamicAnalysis",
    "AbstractShaftToMountableComponentConnectionCompoundDynamicAnalysis",
    "AGMAGleasonConicalGearCompoundDynamicAnalysis",
    "AGMAGleasonConicalGearMeshCompoundDynamicAnalysis",
    "AGMAGleasonConicalGearSetCompoundDynamicAnalysis",
    "AssemblyCompoundDynamicAnalysis",
    "BearingCompoundDynamicAnalysis",
    "BeltConnectionCompoundDynamicAnalysis",
    "BeltDriveCompoundDynamicAnalysis",
    "BevelDifferentialGearCompoundDynamicAnalysis",
    "BevelDifferentialGearMeshCompoundDynamicAnalysis",
    "BevelDifferentialGearSetCompoundDynamicAnalysis",
    "BevelDifferentialPlanetGearCompoundDynamicAnalysis",
    "BevelDifferentialSunGearCompoundDynamicAnalysis",
    "BevelGearCompoundDynamicAnalysis",
    "BevelGearMeshCompoundDynamicAnalysis",
    "BevelGearSetCompoundDynamicAnalysis",
    "BoltCompoundDynamicAnalysis",
    "BoltedJointCompoundDynamicAnalysis",
    "ClutchCompoundDynamicAnalysis",
    "ClutchConnectionCompoundDynamicAnalysis",
    "ClutchHalfCompoundDynamicAnalysis",
    "CoaxialConnectionCompoundDynamicAnalysis",
    "ComponentCompoundDynamicAnalysis",
    "ConceptCouplingCompoundDynamicAnalysis",
    "ConceptCouplingConnectionCompoundDynamicAnalysis",
    "ConceptCouplingHalfCompoundDynamicAnalysis",
    "ConceptGearCompoundDynamicAnalysis",
    "ConceptGearMeshCompoundDynamicAnalysis",
    "ConceptGearSetCompoundDynamicAnalysis",
    "ConicalGearCompoundDynamicAnalysis",
    "ConicalGearMeshCompoundDynamicAnalysis",
    "ConicalGearSetCompoundDynamicAnalysis",
    "ConnectionCompoundDynamicAnalysis",
    "ConnectorCompoundDynamicAnalysis",
    "CouplingCompoundDynamicAnalysis",
    "CouplingConnectionCompoundDynamicAnalysis",
    "CouplingHalfCompoundDynamicAnalysis",
    "CVTBeltConnectionCompoundDynamicAnalysis",
    "CVTCompoundDynamicAnalysis",
    "CVTPulleyCompoundDynamicAnalysis",
    "CycloidalAssemblyCompoundDynamicAnalysis",
    "CycloidalDiscCentralBearingConnectionCompoundDynamicAnalysis",
    "CycloidalDiscCompoundDynamicAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionCompoundDynamicAnalysis",
    "CylindricalGearCompoundDynamicAnalysis",
    "CylindricalGearMeshCompoundDynamicAnalysis",
    "CylindricalGearSetCompoundDynamicAnalysis",
    "CylindricalPlanetGearCompoundDynamicAnalysis",
    "DatumCompoundDynamicAnalysis",
    "ExternalCADModelCompoundDynamicAnalysis",
    "FaceGearCompoundDynamicAnalysis",
    "FaceGearMeshCompoundDynamicAnalysis",
    "FaceGearSetCompoundDynamicAnalysis",
    "FEPartCompoundDynamicAnalysis",
    "FlexiblePinAssemblyCompoundDynamicAnalysis",
    "GearCompoundDynamicAnalysis",
    "GearMeshCompoundDynamicAnalysis",
    "GearSetCompoundDynamicAnalysis",
    "GuideDxfModelCompoundDynamicAnalysis",
    "HypoidGearCompoundDynamicAnalysis",
    "HypoidGearMeshCompoundDynamicAnalysis",
    "HypoidGearSetCompoundDynamicAnalysis",
    "InterMountableComponentConnectionCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundDynamicAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundDynamicAnalysis",
    "MassDiscCompoundDynamicAnalysis",
    "MeasurementComponentCompoundDynamicAnalysis",
    "MicrophoneArrayCompoundDynamicAnalysis",
    "MicrophoneCompoundDynamicAnalysis",
    "MountableComponentCompoundDynamicAnalysis",
    "OilSealCompoundDynamicAnalysis",
    "PartCompoundDynamicAnalysis",
    "PartToPartShearCouplingCompoundDynamicAnalysis",
    "PartToPartShearCouplingConnectionCompoundDynamicAnalysis",
    "PartToPartShearCouplingHalfCompoundDynamicAnalysis",
    "PlanetaryConnectionCompoundDynamicAnalysis",
    "PlanetaryGearSetCompoundDynamicAnalysis",
    "PlanetCarrierCompoundDynamicAnalysis",
    "PointLoadCompoundDynamicAnalysis",
    "PowerLoadCompoundDynamicAnalysis",
    "PulleyCompoundDynamicAnalysis",
    "RingPinsCompoundDynamicAnalysis",
    "RingPinsToDiscConnectionCompoundDynamicAnalysis",
    "RollingRingAssemblyCompoundDynamicAnalysis",
    "RollingRingCompoundDynamicAnalysis",
    "RollingRingConnectionCompoundDynamicAnalysis",
    "RootAssemblyCompoundDynamicAnalysis",
    "ShaftCompoundDynamicAnalysis",
    "ShaftHubConnectionCompoundDynamicAnalysis",
    "ShaftToMountableComponentConnectionCompoundDynamicAnalysis",
    "SpecialisedAssemblyCompoundDynamicAnalysis",
    "SpiralBevelGearCompoundDynamicAnalysis",
    "SpiralBevelGearMeshCompoundDynamicAnalysis",
    "SpiralBevelGearSetCompoundDynamicAnalysis",
    "SpringDamperCompoundDynamicAnalysis",
    "SpringDamperConnectionCompoundDynamicAnalysis",
    "SpringDamperHalfCompoundDynamicAnalysis",
    "StraightBevelDiffGearCompoundDynamicAnalysis",
    "StraightBevelDiffGearMeshCompoundDynamicAnalysis",
    "StraightBevelDiffGearSetCompoundDynamicAnalysis",
    "StraightBevelGearCompoundDynamicAnalysis",
    "StraightBevelGearMeshCompoundDynamicAnalysis",
    "StraightBevelGearSetCompoundDynamicAnalysis",
    "StraightBevelPlanetGearCompoundDynamicAnalysis",
    "StraightBevelSunGearCompoundDynamicAnalysis",
    "SynchroniserCompoundDynamicAnalysis",
    "SynchroniserHalfCompoundDynamicAnalysis",
    "SynchroniserPartCompoundDynamicAnalysis",
    "SynchroniserSleeveCompoundDynamicAnalysis",
    "TorqueConverterCompoundDynamicAnalysis",
    "TorqueConverterConnectionCompoundDynamicAnalysis",
    "TorqueConverterPumpCompoundDynamicAnalysis",
    "TorqueConverterTurbineCompoundDynamicAnalysis",
    "UnbalancedMassCompoundDynamicAnalysis",
    "VirtualComponentCompoundDynamicAnalysis",
    "WormGearCompoundDynamicAnalysis",
    "WormGearMeshCompoundDynamicAnalysis",
    "WormGearSetCompoundDynamicAnalysis",
    "ZerolBevelGearCompoundDynamicAnalysis",
    "ZerolBevelGearMeshCompoundDynamicAnalysis",
    "ZerolBevelGearSetCompoundDynamicAnalysis",
)
